@@ -28,7 +28,7 @@ from .extract import extract_dmg, extract_tar, extract_zip
 from .path import rmtree as junction_rmtree, onerror
 
 
-__all__ = ("BuildFlags", "BuildTask", "Fetcher", "FetcherArgs", "FetcherException")
+__all__ = ("BuildFlags", "BuildTask", "Fetcher", "FetcherArgs", "FetcherException", "Platform")
 
 
 LOG = logging.getLogger('fuzzfetch')
@@ -76,7 +76,9 @@ class HgRevision(object):
         """
         if branch is None or branch == '?':
             raise FetcherException("Can't lookup revision date for branch: %r" % (branch,))
-        if branch != 'try':
+        if branch in {'autoland', 'inbound'}:
+            branch = 'integration/' + branch
+        elif branch != 'try':
             branch = 'mozilla-' + branch
         self._data = _get_url('https://hg.mozilla.org/%s/json-rev/%s' % (branch, revision)).json()
 
@@ -251,8 +253,8 @@ class BuildTask(object):
             task_template_paths = itertools.product(cls.TASKCLUSTER_APIS, task_paths)
 
         elif build == 'latest':
-            if branch == 'try':
-                namespace = 'gecko.v2.try.latest'
+            if branch in {'autoland', 'try'}:
+                namespace = 'gecko.v2.' + branch + '.latest'
             else:
                 namespace = 'gecko.v2.mozilla-' + branch + '.latest'
             product = 'mobile' if 'android' in target_platform else 'firefox'
@@ -300,7 +302,7 @@ class BuildTask(object):
     @classmethod
     def _pushdate_template_paths(cls, pushdate, branch, target_platform):
         """Multiple entries exist per push date. Iterate over all until a working entry is found"""
-        if branch != 'try':
+        if branch not in {'autoland', 'try'}:
             branch = 'mozilla-' + branch
         path = '/namespaces/gecko.v2.' + branch + '.pushdate.' + pushdate
         date_found = False
@@ -328,7 +330,7 @@ class BuildTask(object):
     @classmethod
     def _revision_paths(cls, rev, branch, target_platform):
         """Retrieve the API path for revision based builds"""
-        if branch != 'try':
+        if branch not in {'autoland', 'try'}:
             branch = 'mozilla-' + branch
         namespace = 'gecko.v2.' + branch + '.revision.' + rev
         product = 'mobile' if 'android' in target_platform else 'firefox'
@@ -380,6 +382,8 @@ class FetcherArgs(object):
                                  help='Download from esr-next')
         branch_args.add_argument('--try', action='store_const', const='try', dest='branch',
                                  help='Download from try')
+        branch_args.add_argument('--autoland', action='store_const', const='autoland', dest='branch',
+                                 help='Download from try')
 
         build_group = self.parser.add_argument_group('Build Arguments')
         build_group.add_argument('-d', '--debug', action='store_true',
@@ -391,16 +395,13 @@ class FetcherArgs(object):
         build_group.add_argument('--fuzzing', action='store_true',
                                  help='Download --enable-fuzzing builds.')
         build_group.add_argument('--coverage', action='store_true',
-                                 help='Download --coverage builds. This also pulls down the *.gcno files')
+                                 help='Download --coverage builds.')
         build_group.add_argument('--valgrind', action='store_true',
                                  help='Download Valgrind builds.')
 
         test_group = self.parser.add_argument_group('Test Arguments')
-        test_group.add_argument('--tests', nargs='+', metavar='', choices=Fetcher.TEST_CHOICES,
-                                help=('Download tests associated with this build. Acceptable values are: ' +
-                                      ', '.join(Fetcher.TEST_CHOICES)))
-        test_group.add_argument('--full-symbols', action='store_true',
-                                help='Download the full crashreport-symbols.zip archive.')
+        test_group.add_argument('--gtest', action='store_true',
+                                help='Download gtests associated with this build')
 
         misc_group = self.parser.add_argument_group('Misc. Arguments')
         misc_group.add_argument('-n', '--name',
@@ -470,7 +471,6 @@ class FetcherArgs(object):
 class Fetcher(object):
     """Fetcher fetches build artifacts from TaskCluster and unpacks them"""
     TARGET_CHOICES = {'js', 'firefox'}
-    TEST_CHOICES = {'common', 'reftests', 'gtest'}
     BUILD_ORDER_ASC = 1
     BUILD_ORDER_DESC = 2
     re_target = re.compile(r'(\.linux-(x86_64|i686)(-asan)?|target|mac(64)?|win(32|64))\.json$')
@@ -604,8 +604,8 @@ class Fetcher(object):
                 else:
                     raise FetcherException('Failed to find build near %s' % build)
 
-            if build == 'latest' and (now - self.build_datetime).total_seconds() > 86400:
-                LOG.warning('Latest available build is older than 1 day: %s', self.build_id)
+            if build == 'latest' and (now - self.datetime).total_seconds() > 86400:
+                LOG.warning('Latest available build is older than 1 day: %s', self.id)
 
         else:
             self._task = build
@@ -619,7 +619,7 @@ class Fetcher(object):
             branch = "try"
         else:
             branch = "m-%s" % (self._branch[0],)
-        self._auto_name = '%s%s-%s%s' % (self._platform.auto_name_prefix(), branch, self.build_id, options)
+        self._auto_name = '%s%s-%s%s' % (self._platform.auto_name_prefix(), branch, self.id, options)
 
     @staticmethod
     def resolve_esr(branch):
@@ -672,14 +672,15 @@ class Fetcher(object):
         return self._task.queue_server + ('/task/%s/artifacts' % (self.task_id,))
 
     @property
-    def build_id(self):
+    def id(self):
         """Return the build's id (date stamp)"""
+        # pylint: disable=invalid-name
         return self.build_info['buildid']
 
     @property
-    def build_datetime(self):
+    def datetime(self):
         """Return a datetime representation of the build's id"""
-        return _create_utc_datetime(self.build_id)
+        return _create_utc_datetime(self.id)
 
     @property
     def build_info(self):
@@ -735,18 +736,15 @@ class Fetcher(object):
         """Get the automatic directory name"""
         return self._auto_name
 
-    def extract_build(self, path='.', tests=None, full_symbols=False):
+    def extract_build(self, path='.', gtest=False):
         """
         Download and extract the build and requested extra artifacts
 
         @type path:
         @param path:
 
-        @type tests:
-        @param tests:
-
-        @type full_symbols:
-        @param full_symbols:
+        @type gtest:
+        @param gtest:
         """
         if self._target == 'js':
             self.extract_zip('jsshell.zip', path=os.path.join(path, 'dist', 'bin'))
@@ -772,51 +770,30 @@ class Fetcher(object):
             else:
                 raise FetcherException("'%s' is not a supported platform" % self._platform.system)
 
-        if tests:
-            # validate tests
-            tests = set(tests or [])
-            if not tests.issubset(self.TEST_CHOICES):
-                invalid_test = tuple(tests - self.TEST_CHOICES)[0]
-                raise FetcherException("'%s' is not a supported test type" % invalid_test)
+        if gtest:
+            try:
+                self.extract_tar('gtest.tests.tar.gz', path=path)
+            except FetcherException:
+                self.extract_zip('gtest.tests.zip', path=path)
+            if self._platform.system == 'Windows':
+                libxul = 'xul.dll'
+            elif self._platform.system == 'Linux':
+                libxul = 'libxul.so'
+            elif self._platform.system == 'Darwin':
+                libxul = 'XUL'
+            else:
+                raise FetcherException("'%s' is not a supported platform for gtest" % self._platform.system)
+            os.rename(os.path.join(path, 'gtest', 'gtest_bin', 'gtest', libxul),
+                      os.path.join(path, 'gtest', libxul))
+            shutil.copy(os.path.join(path, 'gtest', 'dependentlibs.list.gtest'),
+                        os.path.join(path, 'dependentlibs.list.gtest'))
 
-            os.mkdir(os.path.join(path, 'tests'))
-            if 'common' in tests:
-                try:
-                    self.extract_tar('common.tests.tar.gz', path=os.path.join(path, 'tests'))
-                except FetcherException:
-                    self.extract_zip('common.tests.zip', path=os.path.join(path, 'tests'))
-            if 'reftests' in tests:
-                try:
-                    self.extract_tar('reftest.tests.tar.gz', path=os.path.join(path, 'tests'))
-                except FetcherException:
-                    self.extract_zip('reftest.tests.zip', path=os.path.join(path, 'tests'))
-            if 'gtest' in tests:
-                try:
-                    self.extract_tar('gtest.tests.tar.gz', path=path)
-                except FetcherException:
-                    self.extract_zip('gtest.tests.zip', path=path)
-                if self._platform.system == 'Windows':
-                    libxul = 'xul.dll'
-                elif self._platform.system == 'Linux':
-                    libxul = 'libxul.so'
-                elif self._platform.system == 'Darwin':
-                    libxul = 'XUL'
-                else:
-                    raise FetcherException("'%s' is not a supported platform for gtest" % self._platform.system)
-                os.rename(os.path.join(path, 'gtest', 'gtest_bin', 'gtest', libxul),
-                          os.path.join(path, 'gtest', libxul))
-                shutil.copy(os.path.join(path, 'gtest', 'dependentlibs.list.gtest'),
-                            os.path.join(path, 'dependentlibs.list.gtest'))
         if self._flags.coverage:
             self.extract_zip('code-coverage-gcno.zip', path=path)
 
         if not self._flags.asan and not self._flags.tsan and not self._flags.valgrind:
-            if full_symbols:
-                symbols = 'crashreporter-symbols-full.zip'
-            else:
-                symbols = 'crashreporter-symbols.zip'
             os.mkdir(os.path.join(path, 'symbols'))
-            self.extract_zip(symbols, path=os.path.join(path, 'symbols'))
+            self.extract_zip('crashreporter-symbols.zip', path=os.path.join(path, 'symbols'))
 
         self._write_fuzzmanagerconf(path)
 
@@ -831,7 +808,7 @@ class Fetcher(object):
         output.add_section('Main')
         output.set('Main', 'platform', self.moz_info['processor'].replace('_', '-'))
         output.set('Main', 'product', 'mozilla-' + self._branch)
-        output.set('Main', 'product_version', '%.8s-%.12s' % (self.build_id, self.changeset))
+        output.set('Main', 'product_version', '%.8s-%.12s' % (self.id, self.changeset))
         # make sure 'os' match what FM expects
         os_name = self.moz_info['os'].lower()
         if os_name.startswith('android'):
@@ -987,8 +964,7 @@ class Fetcher(object):
         extract_options = {
             'dry_run': args.dry_run,
             'out': final_dir,
-            'full_symbols': args.full_symbols,
-            'tests': args.tests
+            'gtest': args.gtest
         }
 
         return obj, extract_options
@@ -1014,7 +990,7 @@ class Fetcher(object):
         LOG.info('> Task ID: %s', obj.task_id)
         LOG.info('> Rank: %s', obj.rank)
         LOG.info('> Changeset: %s', obj.changeset)
-        LOG.info('> Build ID: %s', obj.build_id)
+        LOG.info('> Build ID: %s', obj.id)
 
         if extract_args['dry_run']:
             return
@@ -1023,10 +999,10 @@ class Fetcher(object):
         os.mkdir(out)
 
         try:
-            obj.extract_build(out, tests=extract_args['tests'], full_symbols=extract_args['full_symbols'])
+            obj.extract_build(out, gtest=extract_args['gtest'])
             os.makedirs(os.path.join(out, 'download'))
             with open(os.path.join(out, 'download', 'firefox-temp.txt'), 'a') as dl_fd:
-                dl_fd.write('buildID=' + obj.build_id + os.linesep)
+                dl_fd.write('buildID=' + obj.id + os.linesep)
         except:  # noqa
             if os.path.isdir(out):
                 junction_rmtree(out)
